@@ -1,6 +1,5 @@
 """Data models for Portfolio Manager."""
 
-from collections.abc import Mapping
 from typing import Literal
 
 from pydantic import Field
@@ -27,7 +26,5 @@ class PortfolioRecommendations:
     execution_timeline: Literal["immediate", "gradual", "conditional"] = Field(
         description="Recommended execution approach"
     )
-    expected_outcomes: Mapping[str, str] = Field(
-        description="Projected outcomes by metric, e.g., {'expected_return': '12.5%', 'sharpe_ratio': '1.8', 'max_drawdown': '8%'}"
-    )
+    expected_outcomes: dict[str, str] = Field(description="Expected returns, risks, and other outcomes")
     manager_summary: str = Field(max_length=500, description="Portfolio manager summary")
