@@ -1,6 +1,7 @@
 """Quantitative Analyst specialist module."""
 
 from examples.portfolio_analysis.specialists.quant.models import OpportunitySignal, QuantInsights
+from examples.portfolio_analysis.specialists.quant.node import QuantAnalyst
 from examples.portfolio_analysis.specialists.quant.signature import QuantAnalystSignature
 
-__all__ = ["OpportunitySignal", "QuantAnalystSignature", "QuantInsights"]
+__all__ = ["OpportunitySignal", "QuantAnalyst", "QuantAnalystSignature", "QuantInsights"]
