@@ -1,9 +1,11 @@
 """Risk Analyst specialist module."""
 
 from examples.portfolio_analysis.specialists.risk.models import RiskAssessment, RiskLimitError, RiskMetrics
+from examples.portfolio_analysis.specialists.risk.node import RiskAnalyst
 from examples.portfolio_analysis.specialists.risk.signature import RiskAnalystSignature, RiskLimitSignature
 
 __all__ = [
+    "RiskAnalyst",
     "RiskAnalystSignature",
     "RiskAssessment",
     "RiskLimitError",
